==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-states/include/aws/states/model/MapStateStartedEventDetails.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/states/SFN_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace SFN
{
namespace Model
{

  /**
   * <p>Details about a Map state that was started.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/states-2016-11-23/MapStateStartedEventDetails">AWS
   * API Reference</a></p>
   */
  class AWS_SFN_API MapStateStartedEventDetails
  {
  public:
    MapStateStartedEventDetails();
    MapStateStartedEventDetails(Aws::Utils::Json::JsonView jsonValue);
    MapStateStartedEventDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline int GetLength() const{ return m_length; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline bool LengthHasBeenSet() const { return m_lengthHasBeenSet; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline void SetLength(int value) { m_lengthHasBeenSet = true; m_length = value; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline MapStateStartedEventDetails& WithLength(int value) { SetLength(value); return *this;}

  private:

    int m_length;
    bool m_lengthHasBeenSet;
  };

} // namespace Model
} // namespace SFN
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.9.377-1.src.tar.zst: aws-sdk-cpp-1.9.377/aws-cpp-sdk-states/include/aws/states/model/MapStateStartedEventDetails.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/states/SFN_EXPORTS.h>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace SFN
{
namespace Model
{

  /**
   * <p>Details about a Map state that was started.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/states-2016-11-23/MapStateStartedEventDetails">AWS
   * API Reference</a></p>
   */
  class AWS_SFN_API MapStateStartedEventDetails
  {
  public:
    MapStateStartedEventDetails();
    MapStateStartedEventDetails(Aws::Utils::Json::JsonView jsonValue);
    MapStateStartedEventDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline int GetLength() const{ return m_length; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline bool LengthHasBeenSet() const { return m_lengthHasBeenSet; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline void SetLength(int value) { m_lengthHasBeenSet = true; m_length = value; }

    /**
     * <p>The size of the array for Map state iterations.</p>
     */
    inline MapStateStartedEventDetails& WithLength(int value) { SetLength(value); return *this;}

  private:

    int m_length;
    bool m_lengthHasBeenSet = false;
  };

} // namespace Model
} // namespace SFN
} // namespace Aws
